# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: air/AirQuality.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import FeedHeader_pb2 as FeedHeader__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='air/AirQuality.proto',
  package='air_quality',
  syntax='proto3',
  serialized_options=b'\n\025io.pravah.air.quality',
  serialized_pb=b'\n\x14\x61ir/AirQuality.proto\x12\x0b\x61ir_quality\x1a\x10\x46\x65\x65\x64Header.proto\"V\n\x0b\x46\x65\x65\x64Message\x12\x1b\n\x06header\x18\x01 \x01(\x0b\x32\x0b.FeedHeader\x12*\n\x08stations\x18\x02 \x03(\x0b\x32\x18.air_quality.FeedStation\"V\n\x0b\x46\x65\x65\x64Station\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\ttimestamp\x18\x02 \x01(\x04\x12(\n\x08\x64\x61taList\x18\x03 \x03(\x0b\x32\x16.air_quality.DataPoint\"\xcc\x02\n\tDataPoint\x12)\n\x04type\x18\x01 \x01(\x0e\x32\x1b.air_quality.DataPoint.Type\x12\r\n\x05value\x18\x02 \x01(\x01\x12!\n\x05\x65rror\x18\x03 \x03(\x0b\x32\x12.air_quality.Error\x12\x11\n\ttimestamp\x18\x04 \x01(\x04\"\xce\x01\n\x04Type\x12\t\n\x05PM2_5\x10\x00\x12\x08\n\x04PM10\x10\x01\x12\x06\n\x02NO\x10\x02\x12\x07\n\x03NO2\x10\x03\x12\x07\n\x03NOX\x10\x04\x12\x07\n\x03NH3\x10\x05\x12\x07\n\x03SO2\x10\x06\x12\x06\n\x02\x43O\x10\x07\x12\t\n\x05OZONE\x10\x08\x12\x0b\n\x07\x42\x45NZENE\x10\t\x12\x0b\n\x07TOLUENE\x10\n\x12\x08\n\x04TEMP\x10\x0b\x12\x06\n\x02RH\x10\x0c\x12\x06\n\x02WS\x10\r\x12\x06\n\x02WD\x10\x0e\x12\x06\n\x02\x42P\x10\x0f\x12\r\n\tMP_XYLENE\x10\x10\x12\x06\n\x02SR\x10\x11\x12\x06\n\x02RF\x10\x12\x12\x0f\n\x0b\x45TH_BENZENE\x10\x13\"$\n\x05\x45rror\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x02\x42\x17\n\x15io.pravah.air.qualityb\x06proto3'
  ,
  dependencies=[FeedHeader__pb2.DESCRIPTOR,])



_DATAPOINT_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='air_quality.DataPoint.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PM2_5', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PM10', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO2', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOX', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NH3', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SO2', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CO', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OZONE', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BENZENE', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOLUENE', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TEMP', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RH', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WS', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WD', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BP', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MP_XYLENE', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SR', index=17, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RF', index=18, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ETH_BENZENE', index=19, number=19,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=358,
  serialized_end=564,
)
_sym_db.RegisterEnumDescriptor(_DATAPOINT_TYPE)


_FEEDMESSAGE = _descriptor.Descriptor(
  name='FeedMessage',
  full_name='air_quality.FeedMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='air_quality.FeedMessage.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stations', full_name='air_quality.FeedMessage.stations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55,
  serialized_end=141,
)


_FEEDSTATION = _descriptor.Descriptor(
  name='FeedStation',
  full_name='air_quality.FeedStation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='air_quality.FeedStation.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='air_quality.FeedStation.timestamp', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataList', full_name='air_quality.FeedStation.dataList', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=143,
  serialized_end=229,
)


_DATAPOINT = _descriptor.Descriptor(
  name='DataPoint',
  full_name='air_quality.DataPoint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='air_quality.DataPoint.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='air_quality.DataPoint.value', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='air_quality.DataPoint.error', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='air_quality.DataPoint.timestamp', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DATAPOINT_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=232,
  serialized_end=564,
)


_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='air_quality.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='air_quality.Error.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='air_quality.Error.value', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=566,
  serialized_end=602,
)

_FEEDMESSAGE.fields_by_name['header'].message_type = FeedHeader__pb2._FEEDHEADER
_FEEDMESSAGE.fields_by_name['stations'].message_type = _FEEDSTATION
_FEEDSTATION.fields_by_name['dataList'].message_type = _DATAPOINT
_DATAPOINT.fields_by_name['type'].enum_type = _DATAPOINT_TYPE
_DATAPOINT.fields_by_name['error'].message_type = _ERROR
_DATAPOINT_TYPE.containing_type = _DATAPOINT
DESCRIPTOR.message_types_by_name['FeedMessage'] = _FEEDMESSAGE
DESCRIPTOR.message_types_by_name['FeedStation'] = _FEEDSTATION
DESCRIPTOR.message_types_by_name['DataPoint'] = _DATAPOINT
DESCRIPTOR.message_types_by_name['Error'] = _ERROR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FeedMessage = _reflection.GeneratedProtocolMessageType('FeedMessage', (_message.Message,), {
  'DESCRIPTOR' : _FEEDMESSAGE,
  '__module__' : 'air.AirQuality_pb2'
  # @@protoc_insertion_point(class_scope:air_quality.FeedMessage)
  })
_sym_db.RegisterMessage(FeedMessage)

FeedStation = _reflection.GeneratedProtocolMessageType('FeedStation', (_message.Message,), {
  'DESCRIPTOR' : _FEEDSTATION,
  '__module__' : 'air.AirQuality_pb2'
  # @@protoc_insertion_point(class_scope:air_quality.FeedStation)
  })
_sym_db.RegisterMessage(FeedStation)

DataPoint = _reflection.GeneratedProtocolMessageType('DataPoint', (_message.Message,), {
  'DESCRIPTOR' : _DATAPOINT,
  '__module__' : 'air.AirQuality_pb2'
  # @@protoc_insertion_point(class_scope:air_quality.DataPoint)
  })
_sym_db.RegisterMessage(DataPoint)

Error = _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), {
  'DESCRIPTOR' : _ERROR,
  '__module__' : 'air.AirQuality_pb2'
  # @@protoc_insertion_point(class_scope:air_quality.Error)
  })
_sym_db.RegisterMessage(Error)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
