# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: FeedHeader.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='FeedHeader.proto',
  package='',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=b'\n\x10\x46\x65\x65\x64Header.proto\"\xb7\x01\n\nFeedHeader\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x32\n\x0eincrementality\x18\x02 \x01(\x0e\x32\x1a.FeedHeader.Incrementality\x12\x11\n\ttimestamp\x18\x03 \x01(\x04\x12\x1b\n\x08provider\x18\x04 \x01(\x0b\x32\t.Provider\"4\n\x0eIncrementality\x12\x10\n\x0c\x46ULL_DATASET\x10\x00\x12\x10\n\x0c\x44IFFERENTIAL\x10\x01\"$\n\x08Provider\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\tb\x06proto3'
)



_FEEDHEADER_INCREMENTALITY = _descriptor.EnumDescriptor(
  name='Incrementality',
  full_name='FeedHeader.Incrementality',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FULL_DATASET', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DIFFERENTIAL', index=1, number=1,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=152,
  serialized_end=204,
)
_sym_db.RegisterEnumDescriptor(_FEEDHEADER_INCREMENTALITY)


_FEEDHEADER = _descriptor.Descriptor(
  name='FeedHeader',
  full_name='FeedHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='version', full_name='FeedHeader.version', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='incrementality', full_name='FeedHeader.incrementality', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='FeedHeader.timestamp', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='provider', full_name='FeedHeader.provider', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FEEDHEADER_INCREMENTALITY,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=21,
  serialized_end=204,
)


_PROVIDER = _descriptor.Descriptor(
  name='Provider',
  full_name='Provider',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Provider.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='Provider.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=206,
  serialized_end=242,
)

_FEEDHEADER.fields_by_name['incrementality'].enum_type = _FEEDHEADER_INCREMENTALITY
_FEEDHEADER.fields_by_name['provider'].message_type = _PROVIDER
_FEEDHEADER_INCREMENTALITY.containing_type = _FEEDHEADER
DESCRIPTOR.message_types_by_name['FeedHeader'] = _FEEDHEADER
DESCRIPTOR.message_types_by_name['Provider'] = _PROVIDER
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FeedHeader = _reflection.GeneratedProtocolMessageType('FeedHeader', (_message.Message,), {
  'DESCRIPTOR' : _FEEDHEADER,
  '__module__' : 'FeedHeader_pb2'
  # @@protoc_insertion_point(class_scope:FeedHeader)
  })
_sym_db.RegisterMessage(FeedHeader)

Provider = _reflection.GeneratedProtocolMessageType('Provider', (_message.Message,), {
  'DESCRIPTOR' : _PROVIDER,
  '__module__' : 'FeedHeader_pb2'
  # @@protoc_insertion_point(class_scope:Provider)
  })
_sym_db.RegisterMessage(Provider)


# @@protoc_insertion_point(module_scope)
